@@ -1,5 +1,5 @@
 use crate::keybound::Id;
-use crate::methods::{EvictSetLike, ViewSetLike};
+use crate::methods::{EvictSet, ViewSet};
 
 use std::collections::BTreeMap;
 
@@ -64,7 +64,7 @@ impl <'a, K: Id, V: Id> VOne<'a, K, V> {
     pub fn as_option(&self) -> Option<V> { self.0 }
 }
 
-impl<'a, K: Id, V: Id> EvictSetLike<'a, K, V> for MOne<'a, K, V> {
+impl<'a, K: Id, V: Id> EvictSet<'a, K, V> for MOne<'a, K, V> {
     fn insert(&mut self, v: V, on_evict: impl FnOnce(K, V)) -> Option<V> { 
         self.1.insert(self.0, v, on_evict)
     }
@@ -74,7 +74,7 @@ impl<'a, K: Id, V: Id> EvictSetLike<'a, K, V> for MOne<'a, K, V> {
     }
 }
 
-impl<'a, K: Id, V: Id> ViewSetLike<'a, V> for VOne<'a, K, V> {
+impl<'a, K: Id, V: Id> ViewSet<'a, V> for VOne<'a, K, V> {
     type Iter = impl 'a+Iterator<Item=V>;
 
     fn contains(&self, v: V) -> bool {
@@ -96,7 +96,7 @@ impl<'a, K: Id, V: Id> ViewSetLike<'a, V> for VOne<'a, K, V> {
     }
 }
 
-impl<'a, K: Id, V: Id> ViewSetLike<'a, V> for MOne<'a, K, V> {
+impl<'a, K: Id, V: Id> ViewSet<'a, V> for MOne<'a, K, V> {
     type Iter = impl 'a+Iterator<Item=V>;
 
     fn contains(&self, v: V) -> bool { 
