@@ -1,5 +1,5 @@
 use crate::keybound::Id;
-use crate::methods::{EvictSetLike, ViewSetLike};
+use crate::methods::{EvictSet, ViewSet};
 
 use std::collections::{BTreeSet, BTreeMap};
 
@@ -79,7 +79,7 @@ impl<'a, K: Id, V: Id> MSet<'a, K, V> {
     pub fn key(&self) -> K { self.0 }
 }
 
-impl<'a, K: Id, V: Id> EvictSetLike<'a, K, V> for MSet<'a, K, V> {
+impl<'a, K: Id, V: Id> EvictSet<'a, K, V> for MSet<'a, K, V> {
     fn insert(&mut self, v: V, on_evict: impl FnOnce(K, V)) -> Option<V> { 
         self.1.insert(self.0, v, on_evict)
     }
@@ -90,7 +90,7 @@ impl<'a, K: Id, V: Id> EvictSetLike<'a, K, V> for MSet<'a, K, V> {
 }
 
 
-impl<'a, K: Id, V: Id> ViewSetLike<'a, V> for VSet<'a, K, V> {
+impl<'a, K: Id, V: Id> ViewSet<'a, V> for VSet<'a, K, V> {
     type Iter = impl 'a+Iterator<Item=V>;
 
     fn contains(&self, v: V) -> bool {
@@ -112,7 +112,7 @@ impl<'a, K: Id, V: Id> ViewSetLike<'a, V> for VSet<'a, K, V> {
     }
 }
 
-impl<'a, K: Id, V: Id> ViewSetLike<'a, V> for MSet<'a, K, V> {
+impl<'a, K: Id, V: Id> ViewSet<'a, V> for MSet<'a, K, V> {
     type Iter = impl Iterator<Item=V>;
 
     fn contains(&self, v: V) -> bool { 
